@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Util.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: Util.py 12093 2020-04-19 14:34:56Z Trista $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2018-07-16 17:31:00 +0800 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Author: Trista $ (last)
+# $Date: 2020-04-19 23:34:56 +0900 (週日, 19 四月 2020) $
+# $Revision: 12093 $
 """
 Utilities.
 """
@@ -43,12 +43,27 @@ def populateEnvToSettings(keys, settingsDict, setter=None, evalKeys=None):
     setKeys = []
 
     import os
+    import sys
     from Iuppiter.Util import colored
     
+    args = sys.argv
+
+    # if the command is manage.py runserver, then print the SERVER_MODE
+    if len(args) >= 2:
+        if (args[0].endswith('manage.py')) and (args[1] == 'runserver'):
+            printDetail = True
+        else:
+            printDetail = False
+            
+    # if the command is not manage.py runserver(ex: cms_dumpdata), do NOT print SERVER_MODE
+    else:
+        printDetail = False
+    
     for k in keys:
         if k in os.environ:
-            print("%s found in environment variable, set to settings." % (
-                colored(k, 'yellow', attrs=['bold'])))
+            if printDetail:
+                print("%s found in environment variable, set to settings." % (
+                    colored(k, 'yellow', attrs=['bold'])))
             
             v = os.environ[k]
             if evalKeys and k in evalKeys:
